package com.framework.mvvm.mv

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.Transformations
import androidx.lifecycle.ViewModel
import com.framework.mvvm.model.data.AbsentLiveData
import com.framework.mvvm.model.data.Data
import com.framework.mvvm.model.db.entity.ProjectEntity
import com.framework.mvvm.model.repository.FrameRepository
import com.framework.mvvm.model.vo.FrameRequest


class FrameViewModel(private val repository: FrameRepository) : ViewModel() {
    private val _frameRequest = MutableLiveData<FrameRequest>()

    private var _projects = MutableLiveData<Data<List<ProjectEntity>>>()

    val projects: LiveData<Data<List<ProjectEntity>>> =
        Transformations.switchMap(_frameRequest) { request ->
            if (request == null) {
                AbsentLiveData.create()
            } else {
                repository.getProjects(request)
            }
        }

    fun requestFrame(request: FrameRequest) {
        _frameRequest.value = request
    }

    fun retry() {
        _frameRequest.value?.let {
            _frameRequest.value = it
        }
    }
}